/*****************************************************************************
 *   Copyright (C) 2011 Christian "Cebra" Brandtner, brandtner@brandtner.net *
 *                                                                           *
 *   This program is free software; you can redistribute it and/or modify    *
 *   it under the terms of the GNU General Public License as published by    *
 *   the Free Software Foundation; either version 2 of the License.          *
 *                                                                           *
 *   This program is distributed in the hope that it will be useful,         *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *   GNU General Public License for more details.                            *
 *                                                                           *
 *   You should have received a copy of the GNU General Public License       *
 *   along with this program; if not, write to the                           *
 *   Free Software Foundation, Inc.,                                         *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.               *
 *                                                                           *
 *****************************************************************************/


/*
 * HAL_HW3_7.c
 *
 *  Created on: 13.07.2011
 *      Author: cebra
 *
 *Hardwareabhängige Definitionen und Prozeduren
 * Hardware Leiterplatte V3.7 Cebra
 * USB,Wi232,LED
 */

#ifndef HAL_HW3_7_C_
#define HAL_HW3_7_C_

#include <inttypes.h>
#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>
#include <avr/eeprom.h>
#include <util/delay.h>
//#include <avr/wdt.h>
#include "main.h"

#ifdef HWVERSION3_7

#include "lcd.h"
#include "usart.h"
#include "uart1.h"
//#include "mk-data-structs.h"
//#include "parameter.h"
//#include "menu.h"
#include "display.h"
#include "timer.h"
#include "eeprom.h"
#include "Wi232.h"

#include "motortestI2C.h"
#include "twimaster.h"

/*Hardware 3.7 Portbelegung

Touch					PA0
Touch					PA1
Touch					PA2
Touch					PA3

Key						PA4
Key						PA5
Key						PA6
Key						PA7
........................................................
USB2Wi					PB0		Pin 40		aktiv low
LED3					PB1		Pin	41		LED an +

Display					PB2
Display					PB3
Display					PB4
Display					PB5

LED2      				PB6    	Pin 2       LED an +

Display					PB7
........................................................
I2C						PC0		Pin	19		SCL
I2C						PC1		Pin 20		SDA

USB2FC					PC2		Pin	21		aktiv low
LED1           			PC3    	Pin 22      LED an +
LowBat					PC4		Pin	23		Low Bat Warning Lipo PKT,Input
Uart02Wi				PC5		Pin	24		aktiv low
Uart02FC				PC6		Pin	25		aktiv low
Summer            		PC7    	Pin 26      Summer an +
........................................................
Uart0RxD				PD0
Uart0TxD				PD1
Uart1RxD				PD2
Uart1TxD				PD3

Servo                   PD4    	Pin 13		PWM
Servo 					PD5    	Pin 14		PWM
Wi.232 CMD     			PD6    	Pin 15      aktiv low
Displaybeleuchtung      PD7    	Pin 16      LED an +

*/



void InitHWPorts(void)	/* Initialisierung der Hardware für die jeweilige Leiterplattenversion */

{

	// enable pull ups for the 4 keys
	PORTA |= (1<<PORTA4)|(1<<PORTA5)|(1<<PORTA6)|(1<<PORTA7);

	DDRD |= (1<<DDD7)|(1<<DDD6);
	DDRC |= (1<<DDC2)|(1<<DDC3)|(1<<DDC7); /* Leds,Summer*/

	DDRB = 0xFF;
	set_LED1();
	set_LED2();
	set_LED3();
	set_LED4();
	set_BEEP();
	set_D_LIGHT();
	clr_WI232CMD();
 _delay_ms(250);

	clr_LED1();
	clr_LED2();
	clr_LED3();
	clr_LED4();
	clr_BEEP();

	Display_on = 1;

	LCD_Init ();
	USART_Init (UART_BAUD_SELECT(USART_BAUD,F_CPU));

	uart1_init (UART_BAUD_SELECT(USART_BAUD,F_CPU));      /* USB*/
	uart1_putc('R');
	I2C_Init(1);

	Timer0_Init ();
	TIMER1_Init (); // pwm

	sei ();

	ReadParameter ();
	LCD_Init ();
	InitWi232();

}




#endif
#endif /* HAL_HW3_2_C_ */
